/*
 * Copyright 2010 James Pether Sörling
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: WorldbankApiImplTest.java 5143 2010-12-24 15:04:30Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.external.worldbank/src/test/java/com/hack23/cia/service/external/worldbank/impl/WorldbankApiImplTest.java $
*/
package com.hack23.cia.service.external.worldbank.impl;

import java.util.List;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import com.hack23.cia.model.external.worldbank.countries.impl.CountryElement;
import com.hack23.cia.model.external.worldbank.data.impl.Data;
import com.hack23.cia.model.external.worldbank.indicators.impl.IndicatorElement;
import com.hack23.cia.model.external.worldbank.topic.impl.TopicElement;
import com.hack23.cia.service.external.worldbank.api.WorldBankApi;

/**
 * The Class WorldbankApiImplTest.
 */
public class WorldbankApiImplTest extends AbstractWorldbankFunctionalIntegrationTest {

	/** The worlbank api. */
	@Autowired
	WorldBankApi worlbankApi;

	/**
	 * Gets the countries test.
	 * 
	 * @return the countries test
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void getCountriesTest() throws Exception {
		final List<CountryElement> countries = worlbankApi.getCountries();
		assertNotNull(countries);
		assertTrue("Approx > 230 countries",countries.size() > 230);
	}

	/**
	 * Gets the data test.
	 * 
	 * @return the data test
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void getDataTest() throws Exception {
		final List<Data> data = worlbankApi.getData("br", "SP.POP.TOTL");
		assertNotNull(data);
	}

	/**
	 * Gets the indicators test.
	 * 
	 * @return the indicators test
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void getIndicatorsTest() throws Exception {
		final List<IndicatorElement> indicators = worlbankApi.getIndicators();
		assertNotNull(indicators);
		assertTrue(indicators.size()>1200 );
	}

	/**
	 * Gets the topics test.
	 * 
	 * @return the topics test
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void getTopicsTest() throws Exception {
		final List<TopicElement> topics = worlbankApi.getTopics();
		assertNotNull(topics);
		assertTrue(topics.size()>10 );
	}

}
